# `v0.3.20210220`

- module updates:

  - 3023ddc7a88fe228d4662e7fcc274ce154ac2a23: code: add Quoted helper for easier escaping
    Use it in:
    
    - instapaper
    - reddit2org
    - reddit_all
    - stackexchange
    - vkfavs

  - 4fdb0a815e3fea187cd715e1277711f3807024ad: stackexchange/github: adapt to newer HPI

  - 2fbe94fc43f4c5cc83e827f88a972250d7be7867: vk: reflect HPI updates

- misc

  - CI updates & tox config cleanup, use `hpi module install`


# before `v0.2.20200608`

I used to keep it in [Github releases](https://github.com/karlicoss/orger/releases).
However I realized it's means promoting a silo, so now it's reflected in this file (and only copied to github releases page).
